package com.predic8.tutorial.views;

import android.content.Context;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

import com.predic8.tutorial.R;
import com.predic8.tutorial.model.Background;

public class BackgroundView extends SurfaceView implements Runnable {

	Background bg;
	Thread renderThread;
	SurfaceHolder holder;
	volatile boolean running;

	public BackgroundView(Context context) {
		super(context);
		this.bg = new Background(BitmapFactory.decodeResource(getResources(), R.drawable.background));
		this.holder = getHolder();
	}

	public void resume() {
		running = true;
		renderThread = new Thread(this);
		renderThread.start();
	}

	public void run() {
		while (running) {
			if (!holder.getSurface().isValid())
				continue;
			Canvas canvas = null;
			try {
				canvas = holder.lockCanvas(null);

				synchronized (bg) {
					canvas.drawBitmap(bg.getBitmap(), bg.getX(),0, null);
					
				}
			} finally { 
				if (canvas != null)
					holder.unlockCanvasAndPost(canvas);
			}
		}
	}

	public void pause() {
		running = false;
		while (true) {
			try {
				renderThread.join();
				break;
			} catch (InterruptedException e) {
				// do nothing
			}
		}
	}
	
	public Background getBackgroundModel(){
		return bg;
	}
}